@@ -71,7 +71,8 @@ mockConditionOccurrence <- function(cdm,
 
   concept_id <-
     cdm$concept |>
-    dplyr::filter(.data$domain_id == "Condition") |>
+    dplyr::filter(.data$domain_id == "Condition" &
+                    .data$standard_concept == "S") |>
     dplyr::select("concept_id") |>
     dplyr::pull() |>
     unique()
