@@ -90,7 +90,11 @@ mockVocabularyTables <- function(cdm = mockCdmReference(),
           nam, 2, nchar(nam)
         )
       )
-      cdmTables[[nam]] <- eval(parse(text = tableName))
+
+
+      cdmTables[[nam]] <- eval(parse(text = tableName)) |>
+        addOtherColumns(tableName = snakecase::to_snake_case(nam)) |>
+        correctCdmFormat(tableName = snakecase::to_snake_case(nam))
     }
   }
 
