@@ -10,7 +10,8 @@ test_that("mock observation", {
 
   concept_id <-
     cdm$concept |>
-    dplyr::filter(.data$domain_id == "Observation") |>
+    dplyr::filter(.data$domain_id == "Observation",
+                  .data$standard_concept == "S") |>
     dplyr::select("concept_id") |>
     dplyr::pull() |>
     unique()
